
========================================================
超名的研究方向初探：一个人的学科
========================================================
.. Preliminary discussion of my personal research direction

基本问题：智力的本质
====================

这段时间做AI算法的时候，我一直在思考，人的思维是什么？智能是什么？生命是什么？
What is the difference between the living and the dead?我发现，我们做AI的真正目的，
应该是了解人的认知的本质、了解意识的本质、了解智能的本质。生命是如此奇妙，我们还有如此
多的未知。对我个人而言，我发现，就算目前人工智能能做的事情再怎么牛逼，再怎么绚丽，其实
好像都不令我感到兴奋（相反令很多AI行业外的人感到恐慌）。因为我发现，它并没有让我对于这
个世界，对于我们的智力、意识、思维等的认识，有本质的提高。我们并没有获得更多的关于这个
世界的认知。我们只是知道这东西能玩，至于为什么能玩我们甚至都不清楚。这就是目前人工智能
的问题，它忽略了一些本质的东西。这么火热的人工智能对于研究是一种很不正常的现象。因为，
如果你探究AI为什么会火，你会发现，不是“AI技术突破了”让人工智能火，而是“AI技术突破了，
我们有钱可赚了”才让人工智能火。我个人对于金钱并无执念，再多的物质都比不上一点点认知的
提升。帕斯卡尔在17世纪说过一段话 [1]_ ，他说：

::

	思想形成人的伟大。

	人只不过是一根苇草，是自然界最脆弱的东西；但他是一根能思想的苇草。用不着整个宇宙都
	拿起武器来才能毁灭；一口气、一滴水就足以致他死命了。然而，纵使宇宙毁灭了他，人却仍
	然要比致他于死命的东西更高贵得多；因为他知道自己要死亡，以及宇宙对他所具有的优势，
	而宇宙对此却是一无所知。

	因而，我们全部的尊严就在于思想。正是由于它而不是由于我们所无法填充的空间和时间
	我们才必须提高自己。因此，我们要努力好好地思想；这就是道德的原则。

	能思想的苇草——我应该追求自己的尊严，绝不是求之于空间，而是求之于自己的思想的规定。
	我占有多少土地都不会有用；由于空间，宇宙便囊括了我并吞没了我，有如一个质点；由于思想，
	我却囊括了宇宙。人既不是天使，又不是禽兽；但不幸就在于想表现为天使的人却表现为禽兽。

	思想——人的全部的尊严就在于思想。


的确，这个世界的确很奇妙，我们与这个世界万事万物的最大区别就是，我们是有思想的，我们是有智
力的，我们是有灵魂的。我们再也没有发现过任何一种生物能够比得上我们的智力，我们再也没有发现
任何一个物种能够创造我们创造的精神财富。我们为什么独一无二，就是源于我们的智力，就是帕斯卡尔
所说的我们“唯一的尊严”。

同时，人类真正的难题，也落在，如何认知我们的思维上。“智能的本质是与物质的结构、天体的演化、
生命的起源等几大科学的基本问题并列在一起的又一基本问题” [2]_ 。“物质、生命、宇宙与心智，
一直是纯科学研究的四个本源的探索方面。到了21世纪的今天，有关前三个方面的探索结果，我们都已
经各自建立了基本的科学理论体系，如量子理论、广义相对论、达尔文进化论、遗传学、分子生物学、
大爆炸标准理论、甚至量子引力理论等。但在心智方面，我们却连哪怕是十分简陋的解释理论也没有，
我们对微观的神经活动如何产生宏观的认知行为知之甚少，更没有像广义相对论等那样完整一致的理论
体系。” [3]_

可以发现，这里存在着太多的问题需要去解决。每每想到这儿，我就最不能理解为什么现在学术界的那么
多人都去创业了。我们不过是取得了一点点成绩罢了。更深层次的、更基础的东西，我们都没有明白。我
们目前搞的AI，不过是在盲人摸象。而这种现象在深度学习中表现得最明显。我们是否应该反思，我们
做AI，很多时候，是否我们真正应该做什么都没有搞明白？

人工智能属于工程学科
======================

前面说到，我们真正应该研究的，是思维、智力。那AI在这个角色里面属于什么地位？

钱学森被誉为“科学巨子”、“科学的集大成者”。他在20世纪80年代就开始提倡思维科学。提出创建思维
科学技术部门。他为思维科学构建了比较完整的理论体系。思维科学分为三个层次，基础科学、技术科学、
工程技术。

首先，思维科学的基础科学包括：思维学、信息学。思维学包括抽象（逻辑）思维学、形象（直感）思维学、
灵感（顿悟）思维学。对于信息学，某某某（忘了是谁了）认为人脑思维的过程是处理信息的过程，所以钱
学森认为信息学“理所当然地是思维科学的基础科学之一”。

其次，思维科学的技术科学包括：科学方法论、情报学、数理语言学、结构、模式识别。

最后，思维科学的工程技术包括：密码技术、计算机软件工程、情报资料库技术、文字学、计算机模拟技术、人工智能。

另外，钱老特别提出，思维科学的三个层次之上，是马克思主义哲学。

当然，我不是在推崇钱老的这个学科体系的划分，不管他这个划分在当前是否正确，我觉得将人工智能划分工
程学科就已经道出了本质。将我很多想不明白的问题想明白了。也将我不能释怀的困惑给解释了。比如，人工
智能可能并不真的是我想要的，并不真的是我所渴望的。


计算机认知科学的诞生
=======================

我发现，我真正的兴趣并不在人工智能。我所有的问题，其实大多都集中在人类的认知、思维、智力等问题的
思考上。于是，我给我自己搞了一个学科，叫，计算机认知科学，``Computer Cognitive Science``，简称``CCS``。
不同于计算机科学，也不同于认知科学，也不等同于计算机科学简单地加认知科学。

我这么做的目的，并不是源于自己的自大，也不是为了标榜什么。只是为了加以区分。这个词目前简直是热爆了，
但是我想静一静。于是，我决定自立门户，独开一词，为自己搞一个学科。

这是属于我一个人的学科。我并不需要让外界承认。一个人慢慢搞就可以了。

计算机认知科学中的哲学
========================

我的计算机认知科学的内容目前有点杂，目前不能确定，只能随着时间的流逝让它慢慢发展。但有一点是很明
确的，那就是，哲学。

目前的人工智能缺少一种哲学的思辨，缺乏一种深度，一种内涵。好吧，是我没有感受到。人对于智力、对于思维
的这些的思考，原初就源于我们的一些哲学性的思考。我们问自己，什么是智力？智力是否具有规律？什么使得我
们思维？如果掌握了智力的规律，如果知道我们为什么思维，以及怎么思维，我们是否能造出一台能自主思考的机器？

在人工智能发展如此迅速的今天，我们本该最需要哲学了。来提出、解决一些基础问题。但是这个时代的哲学越来
越少。相反，我在20世纪的文献中却看到了大量的这样的资料。

另外，认知神经科学、认知心理学等是最贴近我所想要的。



``2016-12-18``


.. [1] Pascal, Blaise, and Ernest Havet. Pensées. Dezobry et E. Magdeleine, 1852.
.. [2] 林建祥. "人工智能及其若干哲学问题." 北京大学学报: 哲学社会科学版 2 (1991): 115-123.
.. [3] 意识的科学研究途径. http://blog.sina.com.cn/s/blog_9ee54861010147bo.html


